@@ -4,17 +4,16 @@ Basic usage examples for the Olbrain Python SDK.
 This example demonstrates the fundamental features of the SDK including:
 - Client initialization
 - Session creation
-- Sending messages (sync and streaming)
-- Session management
+- Sending messages (synchronous)
+- Using model overrides
 - Error handling
 """
 
 import os
-from olbrain import AgentClient, ChatResponse, SessionInfo
+from olbrain import AgentClient, ChatResponse
 from olbrain.exceptions import (
     OlbrainError,
     AuthenticationError,
-    SessionNotFoundError,
     NetworkError
 )
 
@@ -47,11 +46,11 @@ def main():
         print(f"Agent URL: {client.agent_url}")
 
         # -----------------------------------------------------------------
-        # Example 1: Synchronous messaging (request-response pattern)
+        # Example 1: Creating a session and sending messages
         # -----------------------------------------------------------------
-        print("\n--- Example 1: Synchronous Messaging ---")
+        print("\n--- Example 1: Create Session and Send Messages ---")
 
-        # Create a session
+        # Create a session (first message without session_id creates the session)
         session_id = client.create_session(
             title="Basic Demo Chat",
             user_id="demo-user-123",
@@ -59,94 +58,81 @@ def main():
         )
         print(f"Session created: {session_id}")
 
-        # Send a message and wait for response
-        response = client.send_and_wait(session_id, "Hello! Can you introduce yourself?")
+        # Send a message and get response
+        response_data = client.send(session_id, "Hello! Can you introduce yourself?")
 
+        # Parse response
+        response = ChatResponse.from_dict(response_data, session_id)
         print(f"Agent: {response.text}")
         if response.token_usage:
             print(f"Tokens used: {response.token_usage.total_tokens}")
+        if response.model:
+            print(f"Model: {response.model}")
+        if response.cost:
+            print(f"Cost: ${response.cost:.6f}")
 
         # Send another message in the same session
-        response2 = client.send_and_wait(session_id, "What can you help me with?")
-        print(f"Agent: {response2.text}")
+        response_data2 = client.send(session_id, "What can you help me with?")
+        response2 = ChatResponse.from_dict(response_data2, session_id)
+        print(f"\nAgent: {response2.text}")
 
         # -----------------------------------------------------------------
-        # Example 2: Real-time streaming (callback pattern)
+        # Example 2: Using model override
         # -----------------------------------------------------------------
-        print("\n--- Example 2: Real-time Streaming ---")
-
-        # Define a callback for incoming messages
-        def on_message(msg):
-            role = msg.get('role', 'unknown')
-            content = msg.get('content', '')
-            print(f"[{role}]: {content}")
-
-        # Create session with streaming enabled
-        streaming_session_id = client.create_session(
-            on_message=on_message,  # Providing callback enables streaming
-            title="Streaming Demo",
-            user_id="demo-user-123"
-        )
-        print(f"Streaming session created: {streaming_session_id}")
-
-        # Send message - response arrives via callback
-        client.send(streaming_session_id, "Tell me a short joke")
-
-        # In a real app, you would call client.run() to block and process messages
-        # For this demo, we'll just wait briefly
-        import time
-        time.sleep(5)  # Wait for streaming response
-
-        # -----------------------------------------------------------------
-        # Example 3: Session management
-        # -----------------------------------------------------------------
-        print("\n--- Example 3: Session Management ---")
-
-        # Get session details
-        info = client.get_session(session_id)
-        print(f"Session title: {info.title}")
-        print(f"Message count: {info.message_count}")
-        print(f"Status: {info.status}")
-
-        # Update session
-        updated = client.update_session(session_id, title="Renamed Demo Chat")
-        print(f"Updated title: {updated.title}")
-
-        # Get session stats
-        stats = client.get_session_stats(session_id)
-        print(f"Session stats: {stats.get('stats', {})}")
-
-        # Get message history
-        messages = client.get_messages(session_id, limit=10)
-        print(f"Retrieved {len(messages.get('messages', []))} messages")
-
-        # -----------------------------------------------------------------
-        # Example 4: Using model override
-        # -----------------------------------------------------------------
-        print("\n--- Example 4: Model Override ---")
+        print("\n--- Example 2: Model Override ---")
 
         # Send message with specific model
-        response = client.send(
+        response_data = client.send(
             session_id,
             "Explain quantum computing in one sentence",
-            model="gpt-4"  # Override default model
+            model="gpt-4o"  # Override default model
         )
-        print(f"Response: {response.get('response', '')}")
+        response = ChatResponse.from_dict(response_data, session_id)
+        print(f"Response: {response.text}")
+        print(f"Model used: {response.model}")
 
         # -----------------------------------------------------------------
-        # Cleanup
+        # Example 3: Using metadata
         # -----------------------------------------------------------------
-        print("\n--- Cleanup ---")
+        print("\n--- Example 3: Message with Metadata ---")
 
-        # Archive sessions when done
-        client.delete_session(session_id)
-        client.delete_session(streaming_session_id)
-        print("Sessions archived")
+        response_data = client.send(
+            session_id,
+            "Tell me a joke",
+            metadata={"category": "humor", "source": "example"}
+        )
+        response = ChatResponse.from_dict(response_data, session_id)
+        print(f"Agent: {response.text}")
+
+        # -----------------------------------------------------------------
+        # Example 4: Multiple sessions
+        # -----------------------------------------------------------------
+        print("\n--- Example 4: Multiple Independent Sessions ---")
+
+        # Create a second session
+        session2_id = client.create_session(
+            title="Second Chat",
+            user_id="another-user"
+        )
+        print(f"Second session created: {session2_id}")
+
+        # Send message to second session
+        response_data = client.send(session2_id, "Hi! What's your favorite color?")
+        response = ChatResponse.from_dict(response_data, session2_id)
+        print(f"Agent (Session 2): {response.text}")
+
+        # Sessions are independent
+        response_data = client.send(
+            session2_id,
+            "Do you remember what I asked in my first session?"
+        )
+        response = ChatResponse.from_dict(response_data, session2_id)
+        print(f"Agent (Session 2): {response.text}")
+
+        print("\nNote: Sessions are independent - each maintains its own conversation context")
 
     except AuthenticationError:
         print("Authentication failed. Please check your API key.")
-    except SessionNotFoundError:
-        print("Session not found.")
     except NetworkError as e:
         print(f"Network error: {e}")
     except OlbrainError as e:
@@ -156,7 +142,7 @@ def main():
     finally:
         if 'client' in locals():
             client.close()
-            print("Client closed")
+            print("\nClient closed")
 
 
 if __name__ == "__main__":
