@@ -1,4 +1,20 @@
 """
+DEPRECATED: Most features in this example are no longer supported.
+
+Session management endpoints (get, update, delete, stats, message history) are not supported
+by the current API (v0.3.0+). The agent API uses a webhook-only architecture.
+
+ONLY the following operations are supported:
+- create_session(): Create a new session (first message without session_id)
+- send(): Send messages to existing sessions
+
+For current usage patterns, see basic_usage.py
+
+This file is kept for reference only and will be removed in a future release.
+
+---
+
+Original documentation (DEPRECATED):
 Session management example for the Olbrain Python SDK.
 
 This example demonstrates:
