@@ -1,4 +1,18 @@
 """
+DEPRECATED: This example is no longer valid.
+
+SSE streaming is not supported by the current API (v0.3.0+).
+The agent API uses a webhook-only architecture and does not provide SSE streaming endpoints.
+
+For current usage patterns, see:
+- basic_usage.py: Synchronous message sending with send()
+- Use send_async() with a webhook URL if you need async processing
+
+This file is kept for reference only and will be removed in a future release.
+
+---
+
+Original documentation (DEPRECATED):
 Streaming responses example for the Olbrain Python SDK.
 
 This example demonstrates:
