@@ -6,6 +6,7 @@ Clean API for agent interaction with real-time message streaming
 import requests
 import logging
 import time
+import warnings
 from typing import Callable, Optional, Dict, Any, List
 
 from .streaming import MessageStream
@@ -170,9 +171,14 @@ class AgentClient:
 
             logger.info(f"Created session {session_id}")
 
-            # Start listening for messages if callback provided
+            # Warn if on_message callback provided (streaming no longer supported)
             if on_message:
-                self.listen(session_id, on_message)
+                warnings.warn(
+                    "on_message callback is no longer supported. SSE streaming has been removed. "
+                    "Use send() for synchronous responses or send_async() with a webhook URL.",
+                    DeprecationWarning,
+                    stacklevel=2
+                )
 
             return session_id
 
@@ -186,7 +192,10 @@ class AgentClient:
         user_id: str = None,
         metadata: Dict[str, Any] = None,
         model: str = None,
-        mode: str = "production"
+        mode: str = "production",
+        attachments: List[Dict] = None,
+        response_mode: str = "sync",
+        webhook_url: str = None
     ) -> Dict[str, Any]:
         """
         Send message to agent. Response comes via callback if listening,
@@ -199,12 +208,15 @@ class AgentClient:
             metadata: Optional message metadata
             model: Optional model override (e.g., 'gpt-4', 'claude-3-opus')
             mode: Session mode - 'development', 'testing', or 'production'
+            attachments: Optional list of file attachments
+            response_mode: Response mode - 'sync' or 'async' (default: 'sync')
+            webhook_url: Webhook URL for async responses (required if response_mode='async')
 
         Returns:
             Response dict with success, response, token_usage, etc.
 
         Raises:
-            ValueError: If message is empty
+            ValueError: If message is empty or webhook_url missing for async mode
             OlbrainError: If send fails
             SessionNotFoundError: If session doesn't exist
 
@@ -215,11 +227,14 @@ class AgentClient:
         if not message or not message.strip():
             raise ValueError("Message cannot be empty")
 
+        if response_mode == "async" and not webhook_url:
+            raise ValueError("webhook_url is required when response_mode='async'")
+
         try:
             payload = {
                 'session_id': session_id,
                 'message': message.strip(),
-                'response_mode': 'sync',
+                'response_mode': response_mode,
                 'mode': mode
             }
             if user_id:
@@ -228,6 +243,10 @@ class AgentClient:
                 payload['metadata'] = metadata
             if model:
                 payload['model'] = model
+            if attachments:
+                payload['attachments'] = attachments
+            if webhook_url:
+                payload['webhook_url'] = webhook_url
 
             response = requests.post(
                 f"{self.agent_url}/api/agent/webhook",
@@ -260,6 +279,9 @@ class AgentClient:
         """
         Send message and wait for response (synchronous).
 
+        DEPRECATED: This method is deprecated. Use send() instead, which provides
+        the same functionality with the correct API endpoint.
+
         This method sends a message and returns a ChatResponse object
         with the agent's reply. Use this for simple request-response patterns.
 
@@ -269,10 +291,10 @@ class AgentClient:
             user_id: Optional user identifier
             metadata: Optional message metadata
             model: Optional model override
-            timeout: Request timeout in seconds (default: 120)
+            timeout: Request timeout in seconds (default: 120, not used)
 
         Returns:
-            ChatResponse with text, token_usage, model_used, etc.
+            ChatResponse with text, token_usage, model, etc.
 
         Raises:
             ValueError: If message is empty
@@ -284,85 +306,122 @@ class AgentClient:
             >>> print(response.text)
             >>> print(f"Tokens used: {response.token_usage.total_tokens}")
         """
-        if not message or not message.strip():
-            raise ValueError("Message cannot be empty")
+        warnings.warn(
+            "send_and_wait() is deprecated and will be removed in v0.4.0. "
+            "Use send() instead, which provides the same functionality.",
+            DeprecationWarning,
+            stacklevel=2
+        )
 
-        try:
-            payload = {
-                'message': message.strip()
-            }
-            if user_id:
-                payload['user_id'] = user_id
-            if metadata:
-                payload['metadata'] = metadata
+        response_data = self.send(
+            session_id=session_id,
+            message=message,
+            user_id=user_id,
+            metadata=metadata,
+            model=model
+        )
+        return ChatResponse.from_dict(response_data, session_id)
 
-            response = requests.post(
-                f"{self.agent_url}/sessions/{session_id}/messages",
-                headers={
-                    'Authorization': f'Bearer {self.api_key}',
-                    'Content-Type': 'application/json'
-                },
-                json=payload,
-                timeout=timeout
-            )
+    def send_async(
+        self,
+        session_id: str,
+        message: str,
+        webhook_url: str,
+        user_id: str = None,
+        metadata: Dict[str, Any] = None,
+        model: str = None,
+        mode: str = "production",
+        attachments: List[Dict] = None
+    ) -> Dict[str, Any]:
+        """
+        Send message with async processing - response delivered to webhook_url.
 
-            self._handle_response_errors(response, "send message")
+        The agent will process the message asynchronously and send the response
+        to the specified webhook URL when ready.
 
-            data = response.json()
-            logger.debug(f"Received response for session {session_id}")
-            return ChatResponse.from_dict(data, session_id)
+        Args:
+            session_id: Session identifier
+            message: Message text to send
+            webhook_url: URL to receive the async response
+            user_id: Optional user identifier
+            metadata: Optional message metadata
+            model: Optional model override
+            mode: Session mode - 'development', 'testing', or 'production'
+            attachments: Optional list of file attachments
 
-        except requests.exceptions.RequestException as e:
-            raise NetworkError(f"Network error sending message: {e}")
+        Returns:
+            Dict with acknowledgment (success, session_id, message)
+
+        Raises:
+            ValueError: If message or webhook_url is empty
+            OlbrainError: If send fails
+
+        Example:
+            >>> result = client.send_async(
+            ...     session_id="sess-123",
+            ...     message="Process this in the background",
+            ...     webhook_url="https://myapp.com/webhook"
+            ... )
+            >>> print(f"Message queued: {result['success']}")
+        """
+        return self.send(
+            session_id=session_id,
+            message=message,
+            user_id=user_id,
+            metadata=metadata,
+            model=model,
+            mode=mode,
+            attachments=attachments,
+            response_mode="async",
+            webhook_url=webhook_url
+        )
 
     def listen(self, session_id: str, on_message: Callable):
         """
         Start listening for messages on existing session
 
+        DEPRECATED: SSE streaming is no longer supported by the current API.
+        The webhook-only API does not provide SSE streaming endpoints.
+
         Args:
             session_id: Session to listen to
             on_message: Callback function(message_dict) for messages
 
+        Raises:
+            NotImplementedError: Always raised as this feature is no longer supported
+
         Example:
-            >>> def handle_msg(msg):
-            ...     print(msg['content'])
-            >>>
-            >>> client.listen("existing-session-id", on_message=handle_msg)
+            >>> # This method is deprecated and will raise NotImplementedError
+            >>> # client.listen("existing-session-id", on_message=handle_msg)
         """
-        if session_id in self._streams:
-            logger.warning(f"Already listening to session {session_id}")
-            return
-
-        stream = MessageStream(
-            agent_url=self.agent_url,
-            api_key=self.api_key,
-            session_id=session_id,
-            on_message=on_message
+        raise NotImplementedError(
+            "SSE streaming is no longer supported. "
+            "The agent API only supports synchronous message sending via the webhook endpoint. "
+            "Use send() for synchronous responses or send_async() with a webhook URL for async processing."
         )
-        stream.start()
-        self._streams[session_id] = stream
-
-        logger.info(f"Started listening to session {session_id}")
 
     def run(self):
         """
         Block forever and process message callbacks
 
+        DEPRECATED: SSE streaming is no longer supported by the current API.
+        The webhook-only API does not provide SSE streaming endpoints.
+
         Call this to keep your program running and receive messages.
         Press Ctrl+C to exit gracefully.
 
-        Example:
-            >>> client.run()  # Blocks until Ctrl+C
-        """
-        self._running = True
-        logger.info("Client running - press Ctrl+C to exit")
+        Raises:
+            NotImplementedError: Always raised as this feature is no longer supported
 
-        try:
-            while self._running:
-                time.sleep(1)
-        except KeyboardInterrupt:
-            logger.info("Received interrupt signal, shutting down...")
-            self.close()
+        Example:
+            >>> # This method is deprecated and will raise NotImplementedError
+            >>> # client.run()  # Blocks until Ctrl+C
+        """
+        raise NotImplementedError(
+            "SSE streaming is no longer supported. "
+            "The agent API only supports synchronous message sending via the webhook endpoint. "
+            "Use send() for synchronous responses or send_async() with a webhook URL for async processing."
+        )
 
     def close(self):
         """
@@ -399,34 +458,24 @@ class AgentClient:
         """
         Get session details.
 
+        DEPRECATED: This method is no longer supported by the current API.
+        The webhook-only API does not provide session management endpoints.
+
         Args:
             session_id: Session identifier
 
-        Returns:
-            SessionInfo with session details
-
         Raises:
-            SessionNotFoundError: If session doesn't exist
-            OlbrainError: If request fails
+            NotImplementedError: Always raised as this feature is no longer supported
 
         Example:
-            >>> info = client.get_session(session_id)
-            >>> print(f"Title: {info.title}, Messages: {info.message_count}")
+            >>> # This method is deprecated and will raise NotImplementedError
+            >>> # info = client.get_session(session_id)
         """
-        try:
-            response = requests.get(
-                f"{self.agent_url}/sessions/{session_id}",
-                headers={'Authorization': f'Bearer {self.api_key}'},
-                timeout=30
-            )
-
-            self._handle_response_errors(response, "get session")
-
-            data = response.json()
-            return SessionInfo.from_dict(data)
-
-        except requests.exceptions.RequestException as e:
-            raise NetworkError(f"Network error getting session: {e}")
+        raise NotImplementedError(
+            "Session management is no longer supported. "
+            "The agent API only supports message sending via the webhook endpoint. "
+            "Use create_session() and send() for message interactions."
+        )
 
     def update_session(
         self,
@@ -438,119 +487,73 @@ class AgentClient:
         """
         Update session details.
 
+        DEPRECATED: This method is no longer supported by the current API.
+        The webhook-only API does not provide session management endpoints.
+
         Args:
             session_id: Session identifier
             title: New session title (optional)
             metadata: New metadata dict (optional)
             status: New status - 'active' or 'archived' (optional)
 
-        Returns:
-            Updated SessionInfo
-
         Raises:
-            SessionNotFoundError: If session doesn't exist
-            OlbrainError: If update fails
+            NotImplementedError: Always raised as this feature is no longer supported
 
         Example:
-            >>> updated = client.update_session(session_id, title="Renamed Chat")
+            >>> # This method is deprecated and will raise NotImplementedError
+            >>> # updated = client.update_session(session_id, title="Renamed Chat")
         """
-        try:
-            payload = {}
-            if title is not None:
-                payload['title'] = title
-            if metadata is not None:
-                payload['metadata'] = metadata
-            if status is not None:
-                if status not in ['active', 'archived']:
-                    raise ValueError("status must be 'active' or 'archived'")
-                payload['status'] = status
-
-            response = requests.put(
-                f"{self.agent_url}/sessions/{session_id}",
-                headers={
-                    'Authorization': f'Bearer {self.api_key}',
-                    'Content-Type': 'application/json'
-                },
-                json=payload,
-                timeout=30
-            )
-
-            self._handle_response_errors(response, "update session")
-
-            data = response.json()
-            return SessionInfo.from_dict(data)
-
-        except requests.exceptions.RequestException as e:
-            raise NetworkError(f"Network error updating session: {e}")
+        raise NotImplementedError(
+            "Session management is no longer supported. "
+            "The agent API only supports message sending via the webhook endpoint. "
+            "Use create_session() and send() for message interactions."
+        )
 
     def delete_session(self, session_id: str) -> Dict[str, Any]:
         """
         Archive/delete a session.
 
+        DEPRECATED: This method is no longer supported by the current API.
+        The webhook-only API does not provide session management endpoints.
+
         Args:
             session_id: Session identifier
 
-        Returns:
-            Dict with success status and archived_at timestamp
-
         Raises:
-            SessionNotFoundError: If session doesn't exist
-            OlbrainError: If delete fails
+            NotImplementedError: Always raised as this feature is no longer supported
 
         Example:
-            >>> result = client.delete_session(session_id)
-            >>> print(f"Archived at: {result['archived_at']}")
+            >>> # This method is deprecated and will raise NotImplementedError
+            >>> # result = client.delete_session(session_id)
         """
-        try:
-            # Stop listening if we have an active stream
-            if session_id in self._streams:
-                self._streams[session_id].stop()
-                del self._streams[session_id]
-
-            response = requests.delete(
-                f"{self.agent_url}/sessions/{session_id}",
-                headers={'Authorization': f'Bearer {self.api_key}'},
-                timeout=30
-            )
-
-            self._handle_response_errors(response, "delete session")
-
-            return response.json()
-
-        except requests.exceptions.RequestException as e:
-            raise NetworkError(f"Network error deleting session: {e}")
+        raise NotImplementedError(
+            "Session management is no longer supported. "
+            "The agent API only supports message sending via the webhook endpoint. "
+            "Sessions are managed automatically by the agent."
+        )
 
     def get_session_stats(self, session_id: str) -> Dict[str, Any]:
         """
         Get session statistics (token usage, message counts, etc.).
 
+        DEPRECATED: This method is no longer supported by the current API.
+        The webhook-only API does not provide session statistics endpoints.
+
         Args:
             session_id: Session identifier
 
-        Returns:
-            Dict with session statistics
-
         Raises:
-            SessionNotFoundError: If session doesn't exist
-            OlbrainError: If request fails
+            NotImplementedError: Always raised as this feature is no longer supported
 
         Example:
-            >>> stats = client.get_session_stats(session_id)
-            >>> print(f"Total tokens: {stats['stats'].get('total_tokens', 0)}")
+            >>> # This method is deprecated and will raise NotImplementedError
+            >>> # stats = client.get_session_stats(session_id)
         """
-        try:
-            response = requests.get(
-                f"{self.agent_url}/sessions/{session_id}/stats",
-                headers={'Authorization': f'Bearer {self.api_key}'},
-                timeout=30
-            )
-
-            self._handle_response_errors(response, "get session stats")
-
-            return response.json()
-
-        except requests.exceptions.RequestException as e:
-            raise NetworkError(f"Network error getting session stats: {e}")
+        raise NotImplementedError(
+            "Session statistics are no longer supported. "
+            "The agent API only supports message sending via the webhook endpoint. "
+            "Token usage is returned with each message response."
+        )
 
     def get_messages(
         self,
@@ -561,37 +564,26 @@ class AgentClient:
         """
         Get message history for a session.
 
+        DEPRECATED: This method is no longer supported by the current API.
+        The webhook-only API does not provide message history endpoints.
+
         Args:
             session_id: Session identifier
             limit: Maximum messages to return (default: 20)
             offset: Number of messages to skip (default: 0)
 
-        Returns:
-            Dict with messages list and pagination info
-
         Raises:
-            SessionNotFoundError: If session doesn't exist
-            OlbrainError: If request fails
+            NotImplementedError: Always raised as this feature is no longer supported
 
         Example:
-            >>> result = client.get_messages(session_id, limit=50)
-            >>> for msg in result['messages']:
-            ...     print(f"{msg['role']}: {msg['content']}")
+            >>> # This method is deprecated and will raise NotImplementedError
+            >>> # result = client.get_messages(session_id, limit=50)
         """
-        try:
-            response = requests.get(
-                f"{self.agent_url}/sessions/{session_id}/messages",
-                headers={'Authorization': f'Bearer {self.api_key}'},
-                params={'limit': limit, 'offset': offset},
-                timeout=30
-            )
-
-            self._handle_response_errors(response, "get messages")
-
-            return response.json()
-
-        except requests.exceptions.RequestException as e:
-            raise NetworkError(f"Network error getting messages: {e}")
+        raise NotImplementedError(
+            "Message history retrieval is no longer supported. "
+            "The agent API only supports message sending via the webhook endpoint. "
+            "You must maintain conversation history in your application if needed."
+        )
 
     # -------------------------------------------------------------------------
     # Helper Methods
